@@ -18,7 +18,16 @@
      SPDX-License-Identifier: AGPL3.0-or-later
  */
 
+#if !defined (__GNUNET_UTIL_LIB_H_INSIDE__)
+#error "Only <gnunet_util_lib.h> can be included directly."
+#endif
+
+
 /**
+ * @addtogroup libgnunetutil
+ * Multi-function utilities library for GNUnet programs
+ * @{
+ *
  * @author Florian Dold
  * @author Christian Grothoff
  *
@@ -35,6 +44,7 @@
 #ifndef GNUNET_MQ_LIB_H
 #define GNUNET_MQ_LIB_H
 
+
 #include "gnunet_scheduler_lib.h"
 
 /**
@@ -305,7 +315,8 @@ enum GNUNET_MQ_PriorityPreferences
  * @param cls closure
  * @param msg the received message
  */
-typedef void (*GNUNET_MQ_MessageCallback) (
+typedef void
+(*GNUNET_MQ_MessageCallback) (
   void *cls,
   const struct GNUNET_MessageHeader *msg);
 
@@ -318,7 +329,8 @@ typedef void (*GNUNET_MQ_MessageCallback) (
  * @return #GNUNET_OK if the message is well-formed,
  *         #GNUNET_SYSERR if not
  */
-typedef int (*GNUNET_MQ_MessageValidationCallback) (
+typedef int
+(*GNUNET_MQ_MessageValidationCallback) (
   void *cls,
   const struct GNUNET_MessageHeader *msg);
 
@@ -331,9 +343,10 @@ typedef int (*GNUNET_MQ_MessageValidationCallback) (
  * @param msg the message to send
  * @param impl_state state of the implementation
  */
-typedef void (*GNUNET_MQ_SendImpl) (struct GNUNET_MQ_Handle *mq,
-                                    const struct GNUNET_MessageHeader *msg,
-                                    void *impl_state);
+typedef void
+(*GNUNET_MQ_SendImpl) (struct GNUNET_MQ_Handle *mq,
+                       const struct GNUNET_MessageHeader *msg,
+                       void *impl_state);
 
 
 /**
@@ -345,8 +358,9 @@ typedef void (*GNUNET_MQ_SendImpl) (struct GNUNET_MQ_Handle *mq,
  * @param mq the message queue to destroy
  * @param impl_state state of the implementation
  */
-typedef void (*GNUNET_MQ_DestroyImpl) (struct GNUNET_MQ_Handle *mq,
-                                       void *impl_state);
+typedef void
+(*GNUNET_MQ_DestroyImpl) (struct GNUNET_MQ_Handle *mq,
+                          void *impl_state);
 
 
 /**
@@ -355,8 +369,9 @@ typedef void (*GNUNET_MQ_DestroyImpl) (struct GNUNET_MQ_Handle *mq,
  * @param mq message queue
  * @param impl_state state specific to the implementation
  */
-typedef void (*GNUNET_MQ_CancelImpl) (struct GNUNET_MQ_Handle *mq,
-                                      void *impl_state);
+typedef void
+(*GNUNET_MQ_CancelImpl) (struct GNUNET_MQ_Handle *mq,
+                         void *impl_state);
 
 
 /**
@@ -368,7 +383,9 @@ typedef void (*GNUNET_MQ_CancelImpl) (struct GNUNET_MQ_Handle *mq,
  * @param cls closure
  * @param error error code
  */
-typedef void (*GNUNET_MQ_ErrorHandler) (void *cls, enum GNUNET_MQ_Error error);
+typedef void
+(*GNUNET_MQ_ErrorHandler) (void *cls,
+                           enum GNUNET_MQ_Error error);
 
 
 /**
@@ -379,9 +396,9 @@ typedef void (*GNUNET_MQ_ErrorHandler) (void *cls, enum GNUNET_MQ_Error error);
  * FIFO of envelopes independent of MQ itself and wants to
  * re-use the pointers internal to @a env.  Use with caution.
  *
- * @param[in|out] env_head of envelope DLL
- * @param[in|out] env_tail tail of envelope DLL
- * @param[in|out] env element to insert at the tail
+ * @param[in,out] env_head of envelope DLL
+ * @param[in,out] env_tail tail of envelope DLL
+ * @param[in,out] env element to insert at the tail
  */
 void
 GNUNET_MQ_dll_insert_head (struct GNUNET_MQ_Envelope **env_head,
@@ -397,9 +414,9 @@ GNUNET_MQ_dll_insert_head (struct GNUNET_MQ_Envelope **env_head,
  * FIFO of envelopes independent of MQ itself and wants to
  * re-use the pointers internal to @a env.  Use with caution.
  *
- * @param[in|out] env_head of envelope DLL
- * @param[in|out] env_tail tail of envelope DLL
- * @param[in|out] env element to insert at the tail
+ * @param[in,out] env_head of envelope DLL
+ * @param[in,out] env_tail tail of envelope DLL
+ * @param[in,out] env element to insert at the tail
  */
 void
 GNUNET_MQ_dll_insert_tail (struct GNUNET_MQ_Envelope **env_head,
@@ -415,9 +432,9 @@ GNUNET_MQ_dll_insert_tail (struct GNUNET_MQ_Envelope **env_head,
  * FIFO of envelopes independent of MQ itself and wants to
  * re-use the pointers internal to @a env.  Use with caution.
  *
- * @param[in|out] env_head of envelope DLL
- * @param[in|out] env_tail tail of envelope DLL
- * @param[in|out] env element to remove from the DLL
+ * @param[in,out] env_head of envelope DLL
+ * @param[in,out] env_tail tail of envelope DLL
+ * @param[in,out] env element to remove from the DLL
  */
 void
 GNUNET_MQ_dll_remove (struct GNUNET_MQ_Envelope **env_head,
@@ -590,6 +607,7 @@ struct GNUNET_MQ_MessageHandler
  *                         "context"),
  *   GNUNET_MQ_handler_end()
  * };
+ * </code>
  *
  * @param name unique basename for the functions
  * @param code message type constant
@@ -821,7 +839,8 @@ GNUNET_MQ_get_length (struct GNUNET_MQ_Handle *mq);
  * @param ev the envelope with the message to send.
  */
 void
-GNUNET_MQ_send (struct GNUNET_MQ_Handle *mq, struct GNUNET_MQ_Envelope *ev);
+GNUNET_MQ_send (struct GNUNET_MQ_Handle *mq,
+                struct GNUNET_MQ_Envelope *ev);
 
 
 /**
@@ -854,7 +873,8 @@ GNUNET_MQ_send_cancel (struct GNUNET_MQ_Envelope *ev);
  * @param assoc_data to associate
  */
 uint32_t
-GNUNET_MQ_assoc_add (struct GNUNET_MQ_Handle *mq, void *assoc_data);
+GNUNET_MQ_assoc_add (struct GNUNET_MQ_Handle *mq,
+                     void *assoc_data);
 
 
 /**
@@ -865,7 +885,8 @@ GNUNET_MQ_assoc_add (struct GNUNET_MQ_Handle *mq, void *assoc_data);
  * @return the associated data
  */
 void *
-GNUNET_MQ_assoc_get (struct GNUNET_MQ_Handle *mq, uint32_t request_id);
+GNUNET_MQ_assoc_get (struct GNUNET_MQ_Handle *mq,
+                     uint32_t request_id);
 
 
 /**
@@ -876,7 +897,8 @@ GNUNET_MQ_assoc_get (struct GNUNET_MQ_Handle *mq, uint32_t request_id);
  * @return the associated data
  */
 void *
-GNUNET_MQ_assoc_remove (struct GNUNET_MQ_Handle *mq, uint32_t request_id);
+GNUNET_MQ_assoc_remove (struct GNUNET_MQ_Handle *mq,
+                        uint32_t request_id);
 
 
 /**
@@ -972,7 +994,7 @@ GNUNET_MQ_destroy_notify_cancel (
  * Call the message message handler that was registered
  * for the type of the given message in the given message queue.
  *
- * This function is indented to be used for the implementation
+ * This function is intended to be used for the implementation
  * of message queues.
  *
  * @param mq message queue with the handlers
@@ -1109,3 +1131,5 @@ GNUNET_MQ_preference_to_string (enum GNUNET_MQ_PreferenceKind type);
 #endif
 
 /** @} */ /* end of group mq */
+
+/** @} */ /* end of group addition */
